import { PromiseFn } from './types';
/**
 * Wraps a promise such that only one call at-a-time may be in execution,
 * any attempt to call the promise while another execution is in progress
 * will result in the second call throwing an exception.
 *
 * (!) Promise should be stable, changing promise while a call is in progress
 * will not affect the outcome nor interrupt the execution.
 *
 * (?) Returned task is assured to be stable, an old result instance will
 * always call the most fresh task.
 *
 * /B 2022-10-19
 */
export declare function useExclusivePromise<R, A extends any[] = []>(fn: PromiseFn<A, R>): PromiseFn<A, R>;
